@@ -1,24 +1,28 @@
 #!/bin/false
-# ABSTRACT: DHCP packet object
+# ABSTRACT: Object methods to create a DHCP packet
+# PODNAME: Net::DHCP
 use strict;
 use warnings;
 
 package Net::DHCP;
-$Net::DHCP::VERSION = '0.7_005';
+$Net::DHCP::VERSION = '0.7_006'; # TRIAL
 
+$Net::DHCP::VERSION = '0.7006';
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Net::DHCP - Object methods to create a DHCP packet.
+Net::DHCP - Object methods to create a DHCP packet
 
 =head1 VERSION
 
-version 0.7_005
+version 0.7_006
 
 =head1 SYNOPSIS
 
@@ -35,25 +39,19 @@ version 0.7_005
 
 Represents a DHCP packet as specified in RFC 1533, RFC 2132.
 
-=head1 AUTHOR
-
-Dean Hamstead E<lt>dean@bytefoundry.com.au<gt>
-
-=head1 SOURCE REPO
-
-See L<https://github.com/djzort/Net-DHCP>
-
-=head1 BUGS
-
-See L<https://rt.cpan.org/Dist/Display.html?Queue=Net-DHCP>
-
-=head1 COPYRIGHT
-
-This is free software. It can be distributed and/or modified under the same terms as
-Perl itself.
-
 =head1 SEE ALSO
 
 L<Net::DHCP::Options>, L<Net::DHCP::Constants>.
 
+=head1 AUTHOR
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
