@@ -1,13 +1,15 @@
 #!/bin/false
-# Net::DHCP::Constants.pm
+# PODNAME: Net::DHCP::Constants
 # Author: Dean Hamstead, Stephan Hadinger
+# ABSTRACT: Constants for DHCP codes and options
 use strict;
 use warnings;
 use 5.8.0;
 
 package Net::DHCP::Constants;
-$Net::DHCP::Constants::VERSION = '0.7_005';
-# standard module declaration
+$Net::DHCP::Constants::VERSION = '0.7_006'; # TRIAL
+
+$Net::DHCP::Constants::VERSION = '0.7006';# standard module declaration
 our ( @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
 use Exporter;
 @ISA     = qw(Exporter);
@@ -455,7 +457,9 @@ our %DHO_FORMATS = (
     DHO_CLASSLESS_STATIC_ROUTE()      => 'csr',        # rfc 3442
     DHO_CCC                           => 'suboptions', # 122
 
-#    DHO_USER_CLASS()  => '',                        # rfc 3004
+    # While not perfect, usage is primarily as a string.  iPXE is
+    # a common use case for this option.
+    DHO_USER_CLASS()                  => 'string',     # rfc 3004
 #    DHO_FQDN()  => '',                              # draft-ietf-dhc-fqdn-option-10.txt
     DHO_DHCP_AGENT_OPTIONS()           => 'suboptions', # rfc 3046
 #    DHO_DHCP_AGENT_OPTIONS()           => 'string',    # rfc 3046
@@ -487,15 +491,19 @@ our %DHO_FORMATS = (
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::DHCP::Constants - Constants for DHCP codes and options
 
 =head1 VERSION
 
-version 0.7_005
+version 0.7_006
 
 =head1 SYNOPSIS
 
@@ -762,8 +770,6 @@ Import all DHCP Agenet (aka Relay Agent) Codes
 53 CARD_VENDOR_DEVICE_ID
 54 CARD_ID
 
-
-
 =back
 
 =head1 TO DO, LIMITATIONS
@@ -784,17 +790,13 @@ L<Net::DHCP::Packet>, L<Net::DHCP::Options>
 
 =head1 AUTHOR
 
-Dean Hamstead E<lt>dean@bytefoundy.com.au<gt> and past Authors (see README)
+Dean Hamstead <dean@bytefoundry.com.au>
 
-=head1 GOT PATCHES?
+=head1 COPYRIGHT AND LICENSE
 
-Many young people like to use Github, so by all means send me pull requests at
+This software is copyright (c) 2016 by Dean Hamstad.
 
-https://github.com/djzort/Net-DHCP
-
-=head1 COPYRIGHT
-
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
