@@ -1,14 +1,16 @@
 #!/bin/false
-# Net::DHCP::Packet.pm
+# PODNAME: Net::DHCP::Packet
 # Author : D. Hamstead
 # Original Author: F. van Dun, S. Hadinger
+# ABSTRACT: Object methods to create a DHCP packet.
 use strict;
 use warnings;
 use 5.8.0;
 
 package Net::DHCP::Packet;
-$Net::DHCP::Packet::VERSION = '0.7_005';
-use Carp;
+$Net::DHCP::Packet::VERSION = '0.7_006'; # TRIAL
+
+$Net::DHCP::Packet::VERSION = '0.7006';use Carp;
 use Net::DHCP::Constants qw(:DEFAULT :dhcp_hashes :dhcp_other %DHO_FORMATS);
 use Net::DHCP::Packet::Attributes qw(:all);
 use Net::DHCP::Packet::IPv4Utils qw(:all);
@@ -205,7 +207,7 @@ sub addSubOptionValue {
     my $code    = shift;    # option code
     my $subcode = shift;    # sub option code
     my $value   = shift;
-    my $value_bin;          # option value in binary format
+    # my $value_bin;          # option value in binary format
 
     # FIXME
     carp("addSubOptionValue: unknown format for code ($code)")
@@ -305,7 +307,7 @@ sub getOptionValue {
 
     return unless defined $value_bin;
 
-    my @values;
+    # my @values;
 
     # hash out these options for speed and sanity
     my %options = (
@@ -787,15 +789,19 @@ sub unpackcsr {
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::DHCP::Packet - Object methods to create a DHCP packet.
 
 =head1 VERSION
 
-version 0.7_005
+version 0.7_006
 
 =head1 SYNOPSIS
 
@@ -903,7 +909,6 @@ Note: DHCP options are created in the same order as key-value pairs.
 
 See L<Net::DHCP::Packet::Attributes>
 
-
 =head2 DHCP OPTIONS METHODS
 
 This section describes how to read or set DHCP options. Methods are given
@@ -952,7 +957,6 @@ If you need access to the raw binary values, please use C<addSubOptionRaw()>.
    $pac->addSubOption(DHO_DHCP_MESSAGE_TYPE(), DHCPINFORM());
    $pac->addSubOption(DHO_NAME_SERVERS(), "10.0.0.1", "10.0.0.2"));
 
-
 =item getOptionValue ( CODE )
 
 Returns the value of a DHCP option.
@@ -1351,30 +1355,20 @@ A simple DHCP Server is provided in the "examples" directory. It is composed of
 "dhcpd.pl" a *very* simple server example, and "dhcpd_test.pl" a simple tester for
 this server.
 
-=head1 AUTHOR
-
-Dean Hamstead E<lt>dean@bytefoundry.com.au<gt>
-Previously Stephan Hadinger E<lt>shadinger@cpan.orgE<gt>.
-Original version by F. van Dun.
-
-=head1 BUGS
-
-See L<https://rt.cpan.org/Dist/Display.html?Queue=Net-DHCP>
-
-=head1 GOT PATCHES?
-
-Many young people like to use Github, so by all means send me pull requests at
-
-https://github.com/djzort/Net-DHCP
-
-=head1 COPYRIGHT
-
-This is free software. It can be distributed and/or modified under the same terms as
-Perl itself.
-
 =head1 SEE ALSO
 
 L<Net::DHCP::Options>, L<Net::DHCP::Constants>, L<Net::DHCP::IPv4Utils>,
 L<Net::DHCP::Attributes>, L<Net::DHCP::OrderOptions>.
 
+=head1 AUTHOR
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
