@@ -1,14 +1,16 @@
 #!/bin/false
-# Net::DHCP::Packet::IPv4Utils.pm
+# PODNAME: Net::DHCP::Packet::IPv4Utils
 # Author : D. Hamstead
 # Original Author: F. van Dun, S. Hadinger
+# ABSTRACT: Object methods for IPv4 in Net::DHCP
 use strict;
 use warnings;
 use 5.8.0;
 
 package Net::DHCP::Packet::IPv4Utils;
-$Net::DHCP::Packet::IPv4Utils::VERSION = '0.7_005';
-# standard module declaration
+$Net::DHCP::Packet::IPv4Utils::VERSION = '0.7_006'; # TRIAL
+
+$Net::DHCP::Packet::IPv4Utils::VERSION = '0.7006';# standard module declaration
 our ( @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
 use Exporter;
 @ISA       = qw(Exporter);
@@ -66,15 +68,19 @@ sub unpackinets_array {    # multiple ip addresses, returns an array
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::DHCP::Packet::IPv4Utils - Object methods for IPv4 in Net::DHCP
 
 =head1 VERSION
 
-version 0.7_005
+version 0.7_006
 
 =head1 SYNOPSIS
 
@@ -84,7 +90,6 @@ version 0.7_005
 
 Probably not at all useful on its own
 
-
 =head2 IPv4 UTILITY METHODS
 
 =over 4
@@ -119,29 +124,19 @@ Transforms a packed bytes list of IP addresses into a array of
 
 =back
 
-=head1 AUTHOR
-
-Dean Hamstead E<lt>dean@bytefoundry.com.au<gt>
-Previously Stephan Hadinger E<lt>shadinger@cpan.orgE<gt>.
-Original version by F. van Dun.
-
-=head1 BUGS
-
-See L<https://rt.cpan.org/Dist/Display.html?Queue=Net-DHCP>
-
-=head1 GOT PATCHES?
-
-Many young people like to use Github, so by all means send me pull requests at
-
-https://github.com/djzort/Net-DHCP
-
-=head1 COPYRIGHT
-
-This is free software. It can be distributed and/or modified under the same terms as
-Perl itself.
-
 =head1 SEE ALSO
 
 L<Net::DHCP::Options>, L<Net::DHCP::Constants>.
 
+=head1 AUTHOR
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
