@@ -1,11 +1,14 @@
 #!/bin/false
+# PODNAME: Net::DHCP::Packet::OrderOptions
+# ABSTRACT: Option ordering logic for Net::DHCP
 use strict;
 use warnings;
 use 5.8.0;
 
 package Net::DHCP::Packet::OrderOptions;
-$Net::DHCP::Packet::OrderOptions::VERSION = '0.7_005';
-# standard module declaration
+$Net::DHCP::Packet::OrderOptions::VERSION = '0.7_006'; # TRIAL
+
+$Net::DHCP::Packet::OrderOptions::VERSION = '0.7006';# standard module declaration
 our ( @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
 use Exporter;
 @ISA       = qw(Exporter);
@@ -296,15 +299,19 @@ sub optionsorder {
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Net::DHCP::Packet::OrderOptions - Option ordering for Net::DHCP::Packet
+Net::DHCP::Packet::OrderOptions - Option ordering logic for Net::DHCP
 
 =head1 VERSION
 
-version 0.7_005
+version 0.7_006
 
 =head1 SYNOPSIS
 
@@ -339,28 +346,20 @@ quirky cliens as possible.
 
 =back
 
-=head1 AUTHOR
-
-Dean Hamstead E<lt>dean@bytefoundry.com.au<gt>
-
-=head1 BUGS
-
-See L<https://rt.cpan.org/Dist/Display.html?Queue=Net-DHCP>
-
-=head1 GOT PATCHES?
-
-Many young people like to use Github, so by all means send me pull requests at
-
-https://github.com/djzort/Net-DHCP
-
-=head1 COPYRIGHT
-
-This is free software. It can be distributed and/or modified under the same terms as
-Perl itself.
-
 =head1 SEE ALSO
 
 L<Net::DHCP>, L<Net::DHCP::Packet>, L<Net::DHCP::Constants>,
 L<dhcp-options>.
 
+=head1 AUTHOR
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
